@@ -5,6 +5,7 @@ from __future__ import annotations
 import binascii
 import contextlib
 import socket
+from collections import Counter
 from ipaddress import AddressValueError, IPv4Address, IPv6Address
 from urllib.parse import unquote_to_bytes, urlsplit
 
@@ -126,6 +127,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"activesheet",
         b"activesearch",
         b"activeworkbook",
+        b"actor",
         b"adodb",
         b"agent",
         b"algorithm",
@@ -286,7 +288,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"http",
         b"httpd",
         b"id",
-        "identification",
+        b"identification",
         b"image",
         b"img",
         b"img1",
@@ -528,6 +530,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"total",
         b"tracing",
         b"track",
+        b"tracker",
         b"trie",
         b"try",
         b"tween",
@@ -1040,6 +1043,12 @@ def domain_is_false_positive(domain: bytes) -> bool:
             return True
         return root in root_fpos
 
+    def freq_of_most_common(data: bytes) -> float:
+        """Get the frequency of the most common character."""
+        counts = Counter(data)
+        most_common_count = counts.most_common(1)[0][1]
+        return most_common_count / len(data)
+
     domain_lower = domain.lower()
     split = domain_lower.split(b".")  # lowering then splitting is faster than lowering each segment
     tld = split[-1]
@@ -1055,6 +1064,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         or b"icrosoft.com".endswith(domain_lower)  # Truncated microsoft.com
         or b"harepoint.com".endswith(domain_lower)  # Truncated sharepoint.com
         or b"utlook.com".endswith(domain_lower)  # Truncated outlook.com
+        or freq_of_most_common(domain_lower) > 0.6  # Junk or padded data
     )
 
 
@@ -1074,21 +1084,28 @@ def find_domains(data: bytes) -> list[Node]:
         if (
             preceeding_character
             and preceeding_character in "\x00\n\t\r"
-            and next_character == "/"
-            and (url_match := re.match(rb"(?ir)https?://([\x00\r\n\ta-z0-9.-]+)", data, endpos=start))
+            and (url_match := re.match(rb"(?ir)https?:[\x00\r\n\t]*//([\x00\r\n\ta-z0-9.-]+)", data, endpos=start))
         ):
-            start = url_match.start(1)
-            domain = data[start:end].translate(bytes(range(256)), delete=b"\x00\r\n\t")
-            obfuscation = "split"
+            if next_character == "/":
+                # We know both the start and end of the domain
+                start = url_match.start(1)
+                domain = data[start:end].translate(bytes(range(256)), delete=b"\x00\r\n\t")
+                obfuscation = "split"
+            else:
+                # We know where the domain starts, but we can't be sure where it ends, discard
+                continue
+
         # Check if the preceeding character where this domain was found in the data is a "%"
         # Some of the URL encoding might be stuck to the domain that was found via regex.
-        elif (
-            re.match(rb"(?ir)(?:[%*]\s?3A|:)\s?[%*]\s?2F\s?[%*]\s?2F", data, endpos=start + 2)
-            or data[start - 1 : start + 2] == b"%40"
-        ):
+        elif re.match(rb"(?ir)(?:[%*=]\s?3A|:)\s?[%*=]\s?2F\s?[%*=]\s?2F", data, endpos=start + 2) or data[
+            start - 1 : start + 2
+        ] in (b"%40", b"=40"):
             # If it is, we need to remove the trailing characters that follow as that's not part of the actual domain.
             domain = domain[2:]
             start = start + 2
+        elif data[start - 1 : start + 4] == b"%2540":
+            domain = domain[4:]
+            start = start + 4
 
         if not is_domain(domain) or len(domain) < 7:
             continue
